SummaryLineItem class

Lightweight representation of a merchant summary line item.

Use SummaryLineItem(label: 'Subtotal', amountCents: 1000) to add lines to the merchant summary that appears above the payment element in the paysheet.

Constructors

SummaryLineItem({required String label, required int amountCents, String? sublabel})
const

Properties

amountCents → int
final
hashCode → int
The hash code for this object.
no setterinherited
label → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sublabel → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited